Class: Views::Docs::Accordion

Inherits:
Base
  • Object
show all
Defined in:
lib/ruby_ui/accordion/accordion_docs.rb

Instance Method Summary collapse

Methods inherited from Base

#Alert, #AlertDescription, #AlertTitle, #Heading, #InlineCode, #InlineLink, #Text, #component_files, #docs_accordion_path, #docs_alert_dialog_path, #docs_alert_path, #docs_aspect_ratio_path, #docs_avatar_path, #docs_badge_path, #docs_installation_path, #docs_separator_path, #docs_sheet_path

Instance Method Details

#view_templateObject



4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/ruby_ui/accordion/accordion_docs.rb', line 4

def view_template
  div(class: "max-w-2xl mx-auto w-full py-10 space-y-10") do
    component = "Accordion"
    render Docs::Header.new(title: component,
      description: "A vertically stacked set of interactive headings that each reveal a section of content.")

    Heading(level: 2) { "Usage" }

    render Docs::VisualCodeExample.new(title: "Example", context: self) do
      @@code = <<~RUBY
        div(class: "w-full") do
          Accordion do
            AccordionItem do
              AccordionTrigger do
                p(class: "font-medium") { "What is PhlexUI?" }
                AccordionIcon()
              end

              AccordionContent do
                p(class: "text-sm pb-4") do
                  "PhlexUI is a UI component library for Ruby devs who want to build better, faster."
                end
              end
            end
          end

          Accordion do
            AccordionItem do
              AccordionTrigger do
                p(class: "font-medium") { "Can I use it with Rails?" }
                AccordionIcon()
              end

              AccordionContent do
                p(class: "text-sm pb-4") do
                  "Yes, PhlexUI is pure Ruby and works great with Rails. It's a Ruby gem that you can install into your Rails app."
                end
              end
            end
          end
        end
      RUBY
    end

    render Components::ComponentSetup::Tabs.new(component_name: component)

    render Docs::ComponentsTable.new(component_files(component))
  end
end