Class: Views::Docs::Alert

Inherits:
Base
  • Object
show all
Defined in:
lib/ruby_ui/alert/alert_docs.rb

Instance Method Summary collapse

Methods inherited from Base

#Alert, #AlertDescription, #AlertTitle, #Heading, #InlineCode, #InlineLink, #Text, #component_files, #docs_accordion_path, #docs_alert_dialog_path, #docs_alert_path, #docs_aspect_ratio_path, #docs_avatar_path, #docs_badge_path, #docs_installation_path, #docs_separator_path, #docs_sheet_path

Instance Method Details

#view_templateObject



4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/ruby_ui/alert/alert_docs.rb', line 4

def view_template
  component = "Alert"
  div(class: "max-w-2xl mx-auto w-full py-10 space-y-10") do
    render Docs::Header.new(title: "Alert", description: "Displays a callout for user attention.")

    Heading(level: 2) { "Usage" }

    render Docs::VisualCodeExample.new(title: "Example", context: self) do
      <<~RUBY
        Alert do
          rocket_icon
          AlertTitle { "Pro tip" }
          AlertDescription { "With RubyUI you'll ship faster." }
        end
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Without Icon", context: self) do
      <<~RUBY
        Alert do
          AlertTitle { "Pro tip" }
          AlertDescription { "Simply, don't include an icon and your alert will look like this." }
        end
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Warning", context: self) do
      <<~RUBY
        Alert(variant: :warning) do
          info_icon
          AlertTitle { "Ship often" }
          AlertDescription { "Shipping is good, your users will thank you for it." }
        end
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Destructive", context: self) do
      <<~RUBY
        Alert(variant: :destructive) do
          alert_icon
          AlertTitle { "Oopsie daisy!" }
          AlertDescription { "Your design system is non-existent." }
        end
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Success", context: self) do
      <<~RUBY
        Alert(variant: :success) do
          check_icon
          AlertTitle { "Installation successful" }
          AlertDescription { "You're all set to start using RubyUI in your application." }
        end
      RUBY
    end

    render Components::ComponentSetup::Tabs.new(component_name: component)

    render Docs::ComponentsTable.new(component_files(component))
  end
end