Class: Views::Docs::AlertDialog

Inherits:
Base
  • Object
show all
Defined in:
lib/ruby_ui/alert_dialog/alert_dialog_docs.rb

Instance Method Summary collapse

Methods inherited from Base

#Alert, #AlertDescription, #AlertTitle, #Heading, #InlineCode, #InlineLink, #Text, #component_files, #docs_accordion_path, #docs_alert_dialog_path, #docs_alert_path, #docs_aspect_ratio_path, #docs_avatar_path, #docs_badge_path, #docs_installation_path, #docs_separator_path, #docs_sheet_path

Instance Method Details

#view_templateObject



4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/ruby_ui/alert_dialog/alert_dialog_docs.rb', line 4

def view_template
  component = "AlertDialog"
  div(class: "max-w-2xl mx-auto w-full py-10 space-y-10") do
    render Docs::Header.new(title: "Alert Dialog", description: "A modal dialog that interrupts the user with important content and expects a response.")

    Heading(level: 2) { "Usage" }
    render Docs::VisualCodeExample.new(title: "Example", context: self) do
      <<~RUBY
        AlertDialog do
          AlertDialogTrigger do
            Button { "Show dialog" }
          end
          AlertDialogContent do
            AlertDialogHeader do
              AlertDialogTitle { "Are you absolutely sure?" }
              AlertDialogDescription { "This action cannot be undone. This will permanently delete your account and remove your data from our servers." }
            end
            AlertDialogFooter do
              AlertDialogCancel { "Cancel" }
              AlertDialogAction { "Continue" } # Will probably be a link to a controller action (e.g. delete account)
            end
          end
        end
      RUBY
    end

    render Components::ComponentSetup::Tabs.new(component_name: component)

    render Docs::ComponentsTable.new(component_files(component))
  end
end