Class: Views::Docs::Checkbox

Inherits:
Base
  • Object
show all
Defined in:
lib/ruby_ui/checkbox/checkbox_docs.rb

Instance Method Summary collapse

Methods inherited from Base

#Alert, #AlertDescription, #AlertTitle, #Heading, #InlineCode, #InlineLink, #Text, #component_files, #docs_accordion_path, #docs_alert_dialog_path, #docs_alert_path, #docs_aspect_ratio_path, #docs_avatar_path, #docs_badge_path, #docs_installation_path, #docs_separator_path, #docs_sheet_path

Instance Method Details

#view_templateObject



4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/ruby_ui/checkbox/checkbox_docs.rb', line 4

def view_template
  component = "Checkbox"
  div(class: "max-w-2xl mx-auto w-full py-10 space-y-10") do
    render Docs::Header.new(title: "Checkbox", description: "A control that allows the user to toggle between checked and not checked.")

    Heading(level: 2) { "Usage" }

    render Docs::VisualCodeExample.new(title: "Example", context: self) do
      <<~RUBY
        div(class: 'flex items-center space-x-3') do
          Checkbox(id: 'terms')
          label(for: 'terms', class: 'text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70') { "Accept terms and conditions" }
        end
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Checked", context: self) do
      <<~RUBY
        div(class: "items-top flex space-x-3") do
          Checkbox(id: 'terms1', checked: true)
          div(class: "grid gap-1.5 leading-none") do
            label(
              for: "terms1",
              class:
                "text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70"
            ) { " Accept terms and conditions " }
            p(class: "text-sm text-muted-foreground") { " You agree to our Terms of Service and Privacy Policy." }
          end
        end
      RUBY
    end

    render Components::ComponentSetup::Tabs.new(component_name: component)

    render Docs::ComponentsTable.new(component_files(component))
  end
end