Class: Views::Docs::Link

Inherits:
Base
  • Object
show all
Defined in:
lib/ruby_ui/link/link_docs.rb

Instance Method Summary collapse

Methods inherited from Base

#Alert, #AlertDescription, #AlertTitle, #Heading, #InlineCode, #InlineLink, #Text, #component_files, #docs_accordion_path, #docs_alert_dialog_path, #docs_alert_path, #docs_aspect_ratio_path, #docs_avatar_path, #docs_badge_path, #docs_installation_path, #docs_separator_path, #docs_sheet_path

Instance Method Details

#view_templateObject



4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/ruby_ui/link/link_docs.rb', line 4

def view_template
  component = "Link"

  div(class: "max-w-2xl mx-auto w-full py-10 space-y-10") do
    render Docs::Header.new(title: "Link", description: "Displays a link that looks like a button or underline link.")

    Heading(level: 2) { "Usage" }

    render Docs::VisualCodeExample.new(title: "Example", description: "This is the default appearance of a Link", context: self) do
      <<~RUBY
        Link(href: "#") { "Link" }
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Aria Disabled", context: self) do
      <<~RUBY
        Link(aria: {disabled: "true"}, href: "#") { "Link" }
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Primary", description: "This is the primary variant of a Link", context: self) do
      <<~RUBY
        Link(href: "#", variant: :primary) { "Primary" }
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Secondary", description: "This is the secondary variant of a Link", context: self) do
      <<~RUBY
        Link(href: "#", variant: :secondary) { "Secondary" }
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Destructive", description: "This is the destructive variant of a Link", context: self) do
      <<~RUBY
        Link(href: "#", variant: :destructive) { "Destructive" }
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Icon", description: "This is the icon variant of a Link", context: self) do
      <<~RUBY
        Link(href: "#", variant: :outline, icon: true) do
          chevron_icon
        end
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "With Icon", description: "This is the primary variant of a Link with an icon", context: self) do
      <<~RUBY
        Link(href: "#", variant: :primary) do
          email_icon
          span { "Login with Email" }
        end
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Ghost", description: "This is the ghost variant of a Link", context: self) do
      <<~RUBY
        Link(href: "#", variant: :ghost) { "Ghost" }
      RUBY
    end

    render Components::ComponentSetup::Tabs.new(component_name: component)

    render Docs::ComponentsTable.new(component_files(component))
  end
end