Class: Views::Docs::Sheet
- Defined in:
- lib/ruby_ui/sheet/sheet_docs.rb
Instance Method Summary collapse
Methods inherited from Base
#Alert, #AlertDescription, #AlertTitle, #Heading, #InlineCode, #InlineLink, #Text, #component_files, #docs_accordion_path, #docs_alert_dialog_path, #docs_alert_path, #docs_aspect_ratio_path, #docs_avatar_path, #docs_badge_path, #docs_installation_path, #docs_separator_path, #docs_sheet_path
Instance Method Details
#view_template ⇒ Object
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/ruby_ui/sheet/sheet_docs.rb', line 4 def view_template component = "Sheet" div(class: "max-w-2xl mx-auto w-full py-10 space-y-10") do render Docs::Header.new(title: "Sheet", description: "Extends the Sheet component to display content that complements the main content of the screen.") Heading(level: 2) { "Usage" } render Docs::VisualCodeExample.new(title: "Example", context: self) do <<~RUBY Sheet do SheetTrigger do Button(variant: :outline) { "Open Sheet" } end SheetContent(class: 'sm:max-w-sm') do SheetHeader do SheetTitle { "Edit profile" } SheetDescription { "Make changes to your profile here. Click save when you're done." } end SheetMiddle do label { "Name" } Input(placeholder: "Joel Drapper") { "Joel Drapper" } label { "Email" } Input(placeholder: "[email protected]") end SheetFooter do Button(variant: :outline, data: { action: 'click->ruby-ui--sheet-content#close' }) { "Cancel" } Button(type: "submit") { "Save" } end end end RUBY end render Docs::VisualCodeExample.new(title: "Side", description: "Use the side property to indicate the edge of the screen where the component will appear.", context: self) do <<~RUBY div(class: 'grid grid-cols-2 gap-4') do # -- TOP -- Sheet do SheetTrigger do Button(variant: :outline, class: 'w-full justify-center') { :top } end SheetContent(side: :top, class: ("sm:max-w-sm" if [:left, :right].include?(:top))) do SheetHeader do SheetTitle { "Edit profile" } SheetDescription { "Make changes to your profile here. Click save when you're done." } end Form do SheetMiddle do label { "Name" } Input(placeholder: "Joel Drapper") { "Joel Drapper" } label { "Email" } Input(placeholder: "[email protected]") end SheetFooter do Button(variant: :outline, data: { action: 'click->ruby-ui--sheet-content#close' }) { "Cancel" } Button(type: "submit") { "Save" } end end end end end RUBY end render Components::ComponentSetup::Tabs.new(component_name: component) render Docs::ComponentsTable.new(component_files(component)) end end |