Class: Views::Docs::Switch

Inherits:
Base
  • Object
show all
Defined in:
lib/ruby_ui/switch/switch_docs.rb

Instance Method Summary collapse

Methods inherited from Base

#Alert, #AlertDescription, #AlertTitle, #Heading, #InlineCode, #InlineLink, #Text, #component_files, #docs_accordion_path, #docs_alert_dialog_path, #docs_alert_path, #docs_aspect_ratio_path, #docs_avatar_path, #docs_badge_path, #docs_installation_path, #docs_separator_path, #docs_sheet_path

Instance Method Details

#view_templateObject



4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/ruby_ui/switch/switch_docs.rb', line 4

def view_template
  component = "Switch"

  div(class: "max-w-2xl mx-auto w-full py-10 space-y-10") do
    render Docs::Header.new(title: "Switch", description: "A control that allows the user to toggle between checked and not checked.")

    Heading(level: 2) { "Usage" }

    render Docs::VisualCodeExample.new(title: "Default", context: self) do
      <<~RUBY
        Switch(name: "switch")
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Checked", context: self) do
      <<~RUBY
        Switch(name: "switch", checked: true)
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Disabled", context: self) do
      <<~RUBY
        Switch(name: "switch", disabled: true)
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "Aria Disabled", context: self) do
      <<~RUBY
        Switch(name: "switch", aria: {disabled: "true"})
      RUBY
    end

    render Docs::VisualCodeExample.new(title: "With flag include_hidden false", context: self) do
      <<~RUBY
        # Supports the creation of a hidden input to be used in forms inspired by the Ruby on Rails implementation of check_box. Default is true.
        Switch(name: "switch", include_hidden: false)
      RUBY
    end

    render Docs::ComponentsTable.new(component_files(component))
  end
end