Class: Views::Docs::Dialog
- Defined in:
- lib/ruby_ui/dialog/dialog_docs.rb
Instance Method Summary collapse
Methods inherited from Base
#Alert, #AlertDescription, #AlertTitle, #Heading, #InlineCode, #InlineLink, #Text, #component_files, #docs_accordion_path, #docs_alert_dialog_path, #docs_alert_path, #docs_aspect_ratio_path, #docs_avatar_path, #docs_badge_path, #docs_installation_path, #docs_separator_path, #docs_sheet_path
Instance Method Details
#view_template ⇒ Object
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/ruby_ui/dialog/dialog_docs.rb', line 4 def view_template component = "Dialog" div(class: "max-w-2xl mx-auto w-full py-10 space-y-10") do render Docs::Header.new(title: "Dialog", description: "A window overlaid on either the primary window or another dialog window, rendering the content underneath inert.") Heading(level: 2) { "Usage" } render Docs::VisualCodeExample.new(title: "Example", context: self) do <<~RUBY Dialog do DialogTrigger do Button { "Open Dialog" } end DialogContent do DialogHeader do DialogTitle { "RubyUI to the rescue" } DialogDescription { "RubyUI helps you build accessible standard compliant web apps with ease" } end DialogMiddle do AspectRatio(aspect_ratio: "16/9", class: 'rounded-md overflow-hidden border') do img( alt: "Placeholder", loading: "lazy", src: image_path("pattern.jpg") ) end end DialogFooter do Button(variant: :outline, data: { action: 'click->ruby-ui--dialog#dismiss' }) { "Cancel" } Button { "Save" } end end end RUBY end render Docs::VisualCodeExample.new(title: "Size", description: "Applicable for wider screens", context: self) do <<~RUBY div(class: 'flex flex-wrap justify-center gap-2') do Dialog do DialogTrigger do Button { "Small Dialog" } end DialogContent(size: :sm) do DialogHeader do DialogTitle { "RubyUI to the rescue" } DialogDescription { "RubyUI helps you build accessible standard compliant web apps with ease" } end DialogMiddle do AspectRatio(aspect_ratio: "16/9", class: 'rounded-md overflow-hidden border') do img( alt: "Placeholder", loading: "lazy", src: image_path("pattern.jpg") ) end end DialogFooter do Button(variant: :outline, data: { action: 'click->ruby-ui--dialog#dismiss' }) { "Cancel" } Button { "Save" } end end end Dialog do DialogTrigger do Button { "Large Dialog" } end DialogContent(size: :lg) do DialogHeader do DialogTitle { "RubyUI to the rescue" } DialogDescription { "RubyUI helps you build accessible standard compliant web apps with ease" } end DialogMiddle do AspectRatio(aspect_ratio: "16/9", class: 'rounded-md overflow-hidden border') do img( alt: "Placeholder", loading: "lazy", src: image_path("pattern.jpg") ) end end DialogFooter do Button(variant: :outline, data: { action: 'click->ruby-ui--dialog#dismiss' }) { "Cancel" } Button { "Save" } end end end end RUBY end render Components::ComponentSetup::Tabs.new(component_name: component) render Docs::ComponentsTable.new(component_files(component)) end end |